=======
Credits
=======

Development Lead
----------------
* **Mojtaba Sardarmehni**, Ph.D. Student <msardar2@ncsu.edu>
* **Amanda Karam**, Ph.D. Student <alkaram@ncsu.edu>
* **Dr. James W. Levis**, Research Assistant Professor <jwlevis@ncsu.edu> 
* **Dr. Detlef Knappe**, S. James Ellen Distinguished Professor <knappe@ncsu.edu>
* **Dr. Morton Barlaz**, Distinguished Univ. Prof. and Dept. Head <barlaz@ncsu.edu >


Contributors
------------
None yet. Why not be the first?


Acknowledgements
----------------
